summaryrefslogtreecommitdiffstats
path: root/qt/ScintillaQt.h
diff options
context:
space:
mode:
authorTimothy Pearson <[email protected]>2011-11-30 12:33:18 -0600
committerTimothy Pearson <[email protected]>2011-11-30 12:33:18 -0600
commit03bc485016127d419bbbbc3cfb09e21e8754b383 (patch)
treecad8234bcf26063239ac7a565298b897ffdeef57 /qt/ScintillaQt.h
parent664e37abfe5c796c1279b8295fb030f126b0a7d8 (diff)
downloadtqscintilla-03bc485016127d419bbbbc3cfb09e21e8754b383.tar.gz
tqscintilla-03bc485016127d419bbbbc3cfb09e21e8754b383.zip
Initial automated TQt conversion
Diffstat (limited to 'qt/ScintillaQt.h')
-rw-r--r--qt/ScintillaQt.h48
1 files changed, 24 insertions, 24 deletions
diff --git a/qt/ScintillaQt.h b/qt/ScintillaQt.h
index 3190b71..08074b3 100644
--- a/qt/ScintillaQt.h
+++ b/qt/ScintillaQt.h
@@ -1,30 +1,30 @@
// The definition of the Qt specific subclass of ScintillaBase.
//
// Copyright (c) 2006
// Riverbank Computing Limited <[email protected]>
//
-// This file is part of QScintilla.
+// This file is part of TQScintilla.
//
-// This copy of QScintilla is free software; you can redistribute it and/or
+// This copy of TQScintilla is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2, or (at your option) any
// later version.
//
-// QScintilla is supplied in the hope that it will be useful, but WITHOUT ANY
+// TQScintilla is supplied in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
// details.
//
// You should have received a copy of the GNU General Public License along with
-// QScintilla; see the file LICENSE. If not, write to the Free Software
+// TQScintilla; see the file LICENSE. If not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-#ifndef SCINTILLAQT_H
-#define SCINTILLAQT_H
+#ifndef SCINTILLATQT_H
+#define SCINTILLATQT_H
-#include <qtimer.h>
+#include <tqtimer.h>
// These are needed because scintilla class header files don't seem to manage
// their own dependencies properly.
@@ -54,27 +54,27 @@
#include "ScintillaBase.h"
-class QPaintEvent;
+class TQPaintEvent;
class QextScintillaBase;
-class QtCallTip;
+class TQtCallTip;
-class ScintillaQt : public ScintillaBase
+class ScintillaTQt : public ScintillaBase
{
friend class QextScintillaBase;
- friend class QtCallTip;
+ friend class TQtCallTip;
public:
- ScintillaQt(QextScintillaBase *qsb_);
- virtual ~ScintillaQt();
+ ScintillaTQt(QextScintillaBase *qsb_);
+ virtual ~ScintillaTQt();
virtual sptr_t WndProc(unsigned int iMessage,uptr_t wParam,
sptr_t lParam);
private:
- QWidget *PWindow(Window &w)
+ TQWidget *PWindow(Window &w)
{
- return reinterpret_cast<QWidget *>(w.GetID());
+ return reinterpret_cast<TQWidget *>(w.GetID());
}
void Initialise();
@@ -99,19 +99,19 @@ private:
void AddToPopUp(const char *label,int cmd = 0,bool enabled = true);
void ClaimSelection();
void UnclaimSelection();
- static sptr_t DirectFunction(ScintillaQt *sci,unsigned int iMessage,
+ static sptr_t DirectFunction(ScintillaTQt *sci,unsigned int iMessage,
uptr_t wParam,sptr_t lParam);
- QString textRange(const SelectionText *text);
- void paintEvent(QPaintEvent *pe);
- void dragEnterEvent(QDragEnterEvent *dee);
- void dragMoveEvent(QDragMoveEvent *dme);
- void dragLeaveEvent(QDragLeaveEvent *dle);
- void dropEvent(QDropEvent *de);
+ TQString textRange(const SelectionText *text);
+ void paintEvent(TQPaintEvent *pe);
+ void dragEnterEvent(TQDragEnterEvent *dee);
+ void dragMoveEvent(TQDragMoveEvent *dme);
+ void dragLeaveEvent(TQDragLeaveEvent *dle);
+ void dropEvent(TQDropEvent *de);
bool capturedMouse;
QextScintillaBase *qsb;
- QTimer qtimer;
+ TQTimer qtimer;
};
#endif
@@ -1,30 +1,30 @@
-// The definition of the Qt specific subclass of ScintillaBase.
+// The definition of the TQt specific subclass of ScintillaBase.
//
// Copyright (c) 2006